@@ -1,16 +1,18 @@
 //! Low-level operations on individual commits.
-use crate::{
-    file::{self, File},
-    graph,
-};
-use byteorder::{BigEndian, ByteOrder};
-use git_hash::SIZE_OF_SHA1_DIGEST as SHA1_SIZE;
 use std::{
     convert::TryInto,
     fmt::{Debug, Formatter},
     slice::Chunks,
 };
 
+use byteorder::{BigEndian, ByteOrder};
+use git_hash::SIZE_OF_SHA1_DIGEST as SHA1_SIZE;
+
+use crate::{
+    file::{self, File, EXTENDED_EDGES_MASK, LAST_EXTENDED_EDGE_MASK, NO_PARENT},
+    graph,
+};
+
 /// The error used in the [`file::commit`][self] module.
 #[derive(thiserror::Error, Debug)]
 #[allow(missing_docs)]
@@ -25,11 +27,6 @@ pub enum Error {
     SecondParentWithoutFirstParent(git_hash::ObjectId),
 }
 
-// Note that git's commit-graph-format.txt as of v2.28.0 gives an incorrect value 0x0700_0000 for
-// NO_PARENT. Fixed in https://github.com/git/git/commit/4d515253afcef985e94400adbfed7044959f9121 .
-const NO_PARENT: u32 = 0x7000_0000;
-const EXTENDED_EDGES_MASK: u32 = 0x8000_0000;
-
 /// A commit as stored in a [`File`].
 pub struct Commit<'a> {
     file: &'a File,
@@ -238,8 +235,6 @@ impl ParentEdge {
     }
 }
 
-const LAST_EXTENDED_EDGE_MASK: u32 = 0x8000_0000;
-
 enum ExtraEdge {
     Internal(graph::Position),
     Last(graph::Position),
